function H = homogeneous_transformation(R, d)
% Inputs:
%   R is a rotation matrix
%   d is a displacement vector
% Remember, this function cannot use variables that are defined outside of
% the function unless they are passed in.  Also, variables defined inside
% of this function cannot be used outside of it, unless they are outputs.

% The file name must match the function name, otherwise Matlab will
% complain.

% Check that the inputs are the right size
assert( isequal(size(R), [3 3])) % R must be a 3x3 matrix
assert( isequal(size(d), [3 1])) % d must be a 3x1 vector

% Check that the determinant of R is +1
if det(R) ~= 1
    error('R is not a rotation matrix. det(R) ~= 1.')
end

% What other condition for a rotation matrix is there?

% Input checking can be very useful when you start dealing with large,
% complicated program that have a lot of functions and a lot of inputs.  If
% you don't check, then Matlab can fail is subtle ways that are hard to
% detect otherwise.

% piece the rotation and translation together into a homogeneous transformation
H = [R d; zeros(1,3) 1];

% You can use the keyboard command to "look inside" a function
% keyboard % uncomment this line

% Type "return" in the command window to exit the keyboard call

% Notice that H is not defined in the base workspace, but it is in the
% function's workspace
